native_source_root_with_warnings

Function native_source_root_with_warnings 

pub fn native_source_root_with_warnings(
    entry: &Path,
) -> (PathBuf, Vec<ConfigWarning>)
Like native_source_root, but additionally reports warnings when the bounded walk stepped over a brink.toml. Returns both the resolved root and any discovery warnings that should be reported to the user.